==> mpiJava-1.2.tar.gz: mpiJava/tests/ccl/scatterv.java <==
/*
 MPI-Java version :
    Sang Lim (slim@npac.syr.edu)
    Northeast Parallel Architectures Center at Syracuse University
    12/2/98
*/

import mpi.*;

class scatterv {
  static public void main(String[] args) {
    
    final int MAXLEN = 10;

    int myself,tasks;
    MPI.Init(args);
    myself = MPI.COMM_WORLD.Rank();
    tasks = MPI.COMM_WORLD.Size();

    int root,i=0,j,k,stride=15;
    int out[] = new int[tasks*stride];
    int in[]  = new int[MAXLEN];
    int dis[] = new int[MAXLEN];
    int scount[] = new int[MAXLEN];

    
    for(i = 0; i < MAXLEN;i++){
       dis[i] = i*stride;
       scount[i] = 5;
       in[i] = 0;
    }
    scount[0] = 10;
    
    for (i = 0;i < tasks*stride;i++)
       out[i] = i;
    
    MPI.COMM_WORLD.Scatterv(out,0,scount,dis,MPI.INT,in,0,scount[myself],MPI.INT,0);

    if(myself==0){
       System.out.println("Original array on root...");
       for(i=0; i<tasks*stride; i++)
          System.out.print(out[i]+" ");
       System.out.println();
       System.out.println();

       System.out.println("Result on proc 0...");
       System.out.println("Stride = 15 "+"Count = "+scount[0]);
       for(i=0; i<MAXLEN; i++)
          System.out.print(in[i]+" ");
       System.out.println();
       System.out.println();
    }
    
    MPI.COMM_WORLD.Barrier();

    if(myself==1){
       System.out.println("Result on proc 1...");
       System.out.println("Stride = 15 "+"Count = "+scount[1]);
       for(i=0; i<MAXLEN; i++)
          System.out.print(in[i]+" ");
       System.out.println();
       System.out.println();
    }

    MPI.COMM_WORLD.Barrier();

    if(myself==2){
       System.out.println("Result on proc 2...");
       System.out.println("Stride = 15 "+"Count = "+scount[2]);
       for(i=0; i<MAXLEN; i++)
          System.out.print(in[i]+" ");
       System.out.println();
    }
    MPI.COMM_WORLD.Barrier();
    if(myself == 0)  System.out.println("Scatterv TEST COMPLETE\n");
    MPI.Finalize();
  }
}

// Things to do
//
//   Make output deterministic by gathering and printing from root.

==> mpiJava-1.2.1.tar.gz: mpiJava/tests/ccl/scatterv.java <==
/*
 MPI-Java version :
    Sang Lim (slim@npac.syr.edu)
    Northeast Parallel Architectures Center at Syracuse University
    12/2/98
*/

import mpi.*;

class scatterv {
  static public void main(String[] args) throws MPIException {
    
    final int MAXLEN = 10;

    int myself,tasks;
    MPI.Init(args);
    myself = MPI.COMM_WORLD.Rank();
    tasks = MPI.COMM_WORLD.Size();

    int root,i=0,j,k,stride=15;
    int out[] = new int[tasks*stride];
    int in[]  = new int[MAXLEN];
    int dis[] = new int[MAXLEN];
    int scount[] = new int[MAXLEN];

    
    for(i = 0; i < MAXLEN;i++){
       dis[i] = i*stride;
       scount[i] = 5;
       in[i] = 0;
    }
    scount[0] = 10;
    
    for (i = 0;i < tasks*stride;i++)
       out[i] = i;
    
    MPI.COMM_WORLD.Scatterv(out,0,scount,dis,MPI.INT,in,0,scount[myself],MPI.INT,0);

    if(myself==0){
       System.out.println("Original array on root...");
       for(i=0; i<tasks*stride; i++)
          System.out.print(out[i]+" ");
       System.out.println();
       System.out.println();

       System.out.println("Result on proc 0...");
       System.out.println("Stride = 15 "+"Count = "+scount[0]);
       for(i=0; i<MAXLEN; i++)
          System.out.print(in[i]+" ");
       System.out.println();
       System.out.println();
    }
    
    MPI.COMM_WORLD.Barrier();

    if(myself==1){
       System.out.println("Result on proc 1...");
       System.out.println("Stride = 15 "+"Count = "+scount[1]);
       for(i=0; i<MAXLEN; i++)
          System.out.print(in[i]+" ");
       System.out.println();
       System.out.println();
    }

    MPI.COMM_WORLD.Barrier();

    if(myself==2){
       System.out.println("Result on proc 2...");
       System.out.println("Stride = 15 "+"Count = "+scount[2]);
       for(i=0; i<MAXLEN; i++)
          System.out.print(in[i]+" ");
       System.out.println();
    }
    MPI.COMM_WORLD.Barrier();
    if(myself == 0)  System.out.println("Scatterv TEST COMPLETE\n");
    MPI.Finalize();
  }
}

// Things to do
//
//   Make output deterministic by gathering and printing from root.
